diff --git a/searx/engines/deezer.py b/searx/engines/deezer.py
new file mode 100644
index 00000000..433ceffa
--- /dev/null
+++ b/searx/engines/deezer.py
@@ -0,0 +1,61 @@
+## Deezer (Music)
+#
+# @website https://deezer.com
+# @provide-api yes (http://developers.deezer.com/api/)
+#
+# @using-api yes
+# @results JSON
+# @stable yes
+# @parse url, title, content, embedded
+
+from json import loads
+from urllib import urlencode
+
+# engine dependent config
+categories = ['music']
+paging = True
+
+# search-url
+url = 'http://api.deezer.com/'
+search_url = url + 'search?{query}&index={offset}'
+
+embedded_url = ''
+
+
+# do search-request
+def request(query, params):
+ offset = (params['pageno'] - 1) * 25
+
+ params['url'] = search_url.format(query=urlencode({'q': query}),
+ offset=offset)
+
+ return params
+
+
+# get response from search-request
+def response(resp):
+ results = []
+
+ search_res = loads(resp.text)
+
+ # parse results
+ for result in search_res.get('data', []):
+ if result['type'] == 'track':
+ title = result['title']
+ url = result['link']
+ content = result['artist']['name'] +\
+ " • " +\
+ result['album']['title'] +\
+ " • " + result['title']
+ embedded = embedded_url.format(audioid=result['id'])
+
+ # append result
+ results.append({'url': url,
+ 'title': title,
+ 'embedded': embedded,
+ 'content': content})
+
+ # return results
+ return results
diff --git a/searx/settings.yml b/searx/settings.yml
index e30c5225..70c56fcc 100644
--- a/searx/settings.yml
+++ b/searx/settings.yml
@@ -35,6 +35,10 @@ engines:
engine : currency_convert
categories : general
shortcut : cc
+
+ - name : deezer
+ engine : deezer
+ shortcut : dz
- name : deviantart
engine : deviantart
diff --git a/searx/static/themes/oscar/js/searx.min.js b/searx/static/themes/oscar/js/searx.min.js
index 34a44f51..d0640f11 100644
Binary files a/searx/static/themes/oscar/js/searx.min.js and b/searx/static/themes/oscar/js/searx.min.js differ
diff --git a/searx/static/themes/oscar/js/searx_src/element_modifiers.js b/searx/static/themes/oscar/js/searx_src/element_modifiers.js
index dd45b77e..8e428054 100644
--- a/searx/static/themes/oscar/js/searx_src/element_modifiers.js
+++ b/searx/static/themes/oscar/js/searx_src/element_modifiers.js
@@ -63,6 +63,18 @@ $(document).ready(function(){
$(this).toggleClass(btnClass);
$(this).toggleClass('btn-default');
});
+
+ /**
+ * change text during btn-toggle click if possible
+ */
+ $('.media-loader').click(function() {
+ var target = $(this).data('target');
+ var iframe_load = $(target + ' > iframe');
+ var srctest = iframe_load.attr('src');
+ if(srctest === undefined || srctest === false){
+ iframe_load.attr('src', iframe_load.data('src'));
+ }
+ });
/**
* Select or deselect every categories on double clic
diff --git a/searx/templates/oscar/result_templates/default.html b/searx/templates/oscar/result_templates/default.html
index 6ab26132..25506b2f 100644
--- a/searx/templates/oscar/result_templates/default.html
+++ b/searx/templates/oscar/result_templates/default.html
@@ -5,6 +5,18 @@
{% if result.publishedDate %}{% endif %}
{{ icon('link') }} {{ _('cached') }}
+{% if result.embedded %}
+ • {{ icon('music') }} {{ _('show media') }}
+{% endif %}
+
+{% if result.embedded %}
+
+{% autoescape false %}
+ {{ result.embedded }}
+{% endautoescape %}
+
+{% endif %}
+
{% if result.content %}{{ result.content|safe }}
{% endif %}
diff --git a/searx/templates/oscar/result_templates/videos.html b/searx/templates/oscar/result_templates/videos.html
index ef4c5dd8..32000e66 100644
--- a/searx/templates/oscar/result_templates/videos.html
+++ b/searx/templates/oscar/result_templates/videos.html
@@ -5,6 +5,18 @@
{% if result.publishedDate %}{% endif %}
{{ icon('link') }} {{ _('cached') }}
+{% if result.embedded %}
+ • {{ icon('film') }} {{ _('show video') }}
+{% endif %}
+
+{% if result.embedded %}
+
+{% autoescape false %}
+ {{ result.embedded }}
+{% endautoescape %}
+
+{% endif %}
+
diff --git a/searx/translations/de/LC_MESSAGES/messages.mo b/searx/translations/de/LC_MESSAGES/messages.mo
index bcfe9dd5..d3800186 100644
Binary files a/searx/translations/de/LC_MESSAGES/messages.mo and b/searx/translations/de/LC_MESSAGES/messages.mo differ
diff --git a/searx/translations/de/LC_MESSAGES/messages.po b/searx/translations/de/LC_MESSAGES/messages.po
index 1639d789..6c6a53da 100644
--- a/searx/translations/de/LC_MESSAGES/messages.po
+++ b/searx/translations/de/LC_MESSAGES/messages.po
@@ -10,7 +10,7 @@ msgid ""
msgstr ""
"Project-Id-Version: searx\n"
"Report-Msgid-Bugs-To: EMAIL@ADDRESS\n"
-"POT-Creation-Date: 2014-12-27 14:39+0100\n"
+"POT-Creation-Date: 2015-01-05 20:54+0100\n"
"PO-Revision-Date: 2014-12-27 10:30+0000\n"
"Last-Translator: pointhi\n"
"Language-Team: German "
@@ -21,11 +21,11 @@ msgstr ""
"Content-Transfer-Encoding: 8bit\n"
"Generated-By: Babel 1.3\n"
-#: searx/webapp.py:247
+#: searx/webapp.py:263
msgid "{minutes} minute(s) ago"
msgstr "vor {minutes} Minute(n)"
-#: searx/webapp.py:249
+#: searx/webapp.py:265
msgid "{hours} hour(s), {minutes} minute(s) ago"
msgstr "vor {hours} Stunde(n), {minutes} Minute(n)"
@@ -173,31 +173,31 @@ msgstr "Zurück"
#: searx/templates/courgette/results.html:12
#: searx/templates/default/results.html:12
-#: searx/templates/oscar/results.html:83
+#: searx/templates/oscar/results.html:87
msgid "Search URL"
msgstr "Such-URL"
#: searx/templates/courgette/results.html:16
#: searx/templates/default/results.html:16
-#: searx/templates/oscar/results.html:88
+#: searx/templates/oscar/results.html:92
msgid "Download results"
msgstr "Ergebnisse herunterladen"
#: searx/templates/courgette/results.html:34
#: searx/templates/default/results.html:42
-#: searx/templates/oscar/results.html:63
+#: searx/templates/oscar/results.html:67
msgid "Suggestions"
msgstr "Vorschläge"
#: searx/templates/courgette/results.html:62
#: searx/templates/default/results.html:78
-#: searx/templates/oscar/results.html:37
+#: searx/templates/oscar/results.html:41
msgid "previous page"
msgstr "vorherige Seite"
#: searx/templates/courgette/results.html:73
#: searx/templates/default/results.html:89
-#: searx/templates/oscar/results.html:45
+#: searx/templates/oscar/results.html:49
msgid "next page"
msgstr "nächste Seite"
@@ -276,7 +276,7 @@ msgstr "ändere das Aussehen von searx"
msgid "Search results"
msgstr "Suchergebnisse"
-#: searx/templates/oscar/results.html:78
+#: searx/templates/oscar/results.html:82
msgid "Links"
msgstr "Links"
@@ -360,6 +360,14 @@ msgstr "Irgendetwas ist falsch gelaufen."
msgid "cached"
msgstr "Im Cache"
+#: searx/templates/oscar/result_templates/default.html:9
+msgid "show media"
+msgstr ""
+
+#: searx/templates/oscar/result_templates/default.html:9
+msgid "hide media"
+msgstr ""
+
#: searx/templates/oscar/result_templates/images.html:21
msgid "Get image"
msgstr "Bild ansehen"
@@ -392,6 +400,14 @@ msgstr "Seeder"
msgid "Leecher"
msgstr "Leecher"
+#: searx/templates/oscar/result_templates/videos.html:9
+msgid "show video"
+msgstr ""
+
+#: searx/templates/oscar/result_templates/videos.html:9
+msgid "hide video"
+msgstr ""
+
msgid "Localization"
msgstr "Übersetzung"
diff --git a/searx/translations/en/LC_MESSAGES/messages.mo b/searx/translations/en/LC_MESSAGES/messages.mo
index 9d746c2b..c3099bf2 100644
Binary files a/searx/translations/en/LC_MESSAGES/messages.mo and b/searx/translations/en/LC_MESSAGES/messages.mo differ
diff --git a/searx/translations/en/LC_MESSAGES/messages.po b/searx/translations/en/LC_MESSAGES/messages.po
index 07948d1a..cd807e6a 100644
--- a/searx/translations/en/LC_MESSAGES/messages.po
+++ b/searx/translations/en/LC_MESSAGES/messages.po
@@ -7,7 +7,7 @@ msgid ""
msgstr ""
"Project-Id-Version: PROJECT VERSION\n"
"Report-Msgid-Bugs-To: EMAIL@ADDRESS\n"
-"POT-Creation-Date: 2014-12-27 14:39+0100\n"
+"POT-Creation-Date: 2015-01-05 20:54+0100\n"
"PO-Revision-Date: 2014-01-30 15:22+0100\n"
"Last-Translator: FULL NAME
\n"
"Language-Team: en \n"
@@ -17,11 +17,11 @@ msgstr ""
"Content-Transfer-Encoding: 8bit\n"
"Generated-By: Babel 1.3\n"
-#: searx/webapp.py:247
+#: searx/webapp.py:263
msgid "{minutes} minute(s) ago"
msgstr ""
-#: searx/webapp.py:249
+#: searx/webapp.py:265
msgid "{hours} hour(s), {minutes} minute(s) ago"
msgstr ""
@@ -165,31 +165,31 @@ msgstr ""
#: searx/templates/courgette/results.html:12
#: searx/templates/default/results.html:12
-#: searx/templates/oscar/results.html:83
+#: searx/templates/oscar/results.html:87
msgid "Search URL"
msgstr ""
#: searx/templates/courgette/results.html:16
#: searx/templates/default/results.html:16
-#: searx/templates/oscar/results.html:88
+#: searx/templates/oscar/results.html:92
msgid "Download results"
msgstr ""
#: searx/templates/courgette/results.html:34
#: searx/templates/default/results.html:42
-#: searx/templates/oscar/results.html:63
+#: searx/templates/oscar/results.html:67
msgid "Suggestions"
msgstr ""
#: searx/templates/courgette/results.html:62
#: searx/templates/default/results.html:78
-#: searx/templates/oscar/results.html:37
+#: searx/templates/oscar/results.html:41
msgid "previous page"
msgstr ""
#: searx/templates/courgette/results.html:73
#: searx/templates/default/results.html:89
-#: searx/templates/oscar/results.html:45
+#: searx/templates/oscar/results.html:49
msgid "next page"
msgstr ""
@@ -265,7 +265,7 @@ msgstr ""
msgid "Search results"
msgstr ""
-#: searx/templates/oscar/results.html:78
+#: searx/templates/oscar/results.html:82
msgid "Links"
msgstr ""
@@ -346,6 +346,14 @@ msgstr ""
msgid "cached"
msgstr ""
+#: searx/templates/oscar/result_templates/default.html:9
+msgid "show media"
+msgstr ""
+
+#: searx/templates/oscar/result_templates/default.html:9
+msgid "hide media"
+msgstr ""
+
#: searx/templates/oscar/result_templates/images.html:21
msgid "Get image"
msgstr ""
@@ -378,6 +386,14 @@ msgstr ""
msgid "Leecher"
msgstr ""
+#: searx/templates/oscar/result_templates/videos.html:9
+msgid "show video"
+msgstr ""
+
+#: searx/templates/oscar/result_templates/videos.html:9
+msgid "hide video"
+msgstr ""
+
msgid "Localization"
msgstr ""
diff --git a/searx/translations/es/LC_MESSAGES/messages.mo b/searx/translations/es/LC_MESSAGES/messages.mo
index e737b1cd..8a36374f 100644
Binary files a/searx/translations/es/LC_MESSAGES/messages.mo and b/searx/translations/es/LC_MESSAGES/messages.mo differ
diff --git a/searx/translations/es/LC_MESSAGES/messages.po b/searx/translations/es/LC_MESSAGES/messages.po
index 686c0f46..6f336bf1 100644
--- a/searx/translations/es/LC_MESSAGES/messages.po
+++ b/searx/translations/es/LC_MESSAGES/messages.po
@@ -8,7 +8,7 @@ msgid ""
msgstr ""
"Project-Id-Version: searx\n"
"Report-Msgid-Bugs-To: EMAIL@ADDRESS\n"
-"POT-Creation-Date: 2014-12-27 14:39+0100\n"
+"POT-Creation-Date: 2015-01-05 20:54+0100\n"
"PO-Revision-Date: 2014-11-26 20:38+0000\n"
"Last-Translator: Adam Tauber \n"
"Language-Team: Spanish "
@@ -19,11 +19,11 @@ msgstr ""
"Content-Transfer-Encoding: 8bit\n"
"Generated-By: Babel 1.3\n"
-#: searx/webapp.py:247
+#: searx/webapp.py:263
msgid "{minutes} minute(s) ago"
msgstr "hace {minutes} minuto(s)"
-#: searx/webapp.py:249
+#: searx/webapp.py:265
msgid "{hours} hour(s), {minutes} minute(s) ago"
msgstr "hace {hours} hora(s) y {minutes} minuto(s)"
@@ -171,31 +171,31 @@ msgstr "Atrás"
#: searx/templates/courgette/results.html:12
#: searx/templates/default/results.html:12
-#: searx/templates/oscar/results.html:83
+#: searx/templates/oscar/results.html:87
msgid "Search URL"
msgstr "Buscar URL"
#: searx/templates/courgette/results.html:16
#: searx/templates/default/results.html:16
-#: searx/templates/oscar/results.html:88
+#: searx/templates/oscar/results.html:92
msgid "Download results"
msgstr "Descargar resultados"
#: searx/templates/courgette/results.html:34
#: searx/templates/default/results.html:42
-#: searx/templates/oscar/results.html:63
+#: searx/templates/oscar/results.html:67
msgid "Suggestions"
msgstr "Sugerencias"
#: searx/templates/courgette/results.html:62
#: searx/templates/default/results.html:78
-#: searx/templates/oscar/results.html:37
+#: searx/templates/oscar/results.html:41
msgid "previous page"
msgstr "Página anterior"
#: searx/templates/courgette/results.html:73
#: searx/templates/default/results.html:89
-#: searx/templates/oscar/results.html:45
+#: searx/templates/oscar/results.html:49
msgid "next page"
msgstr "Página siguiente"
@@ -271,7 +271,7 @@ msgstr ""
msgid "Search results"
msgstr ""
-#: searx/templates/oscar/results.html:78
+#: searx/templates/oscar/results.html:82
msgid "Links"
msgstr ""
@@ -352,6 +352,14 @@ msgstr ""
msgid "cached"
msgstr ""
+#: searx/templates/oscar/result_templates/default.html:9
+msgid "show media"
+msgstr ""
+
+#: searx/templates/oscar/result_templates/default.html:9
+msgid "hide media"
+msgstr ""
+
#: searx/templates/oscar/result_templates/images.html:21
msgid "Get image"
msgstr ""
@@ -384,6 +392,14 @@ msgstr ""
msgid "Leecher"
msgstr ""
+#: searx/templates/oscar/result_templates/videos.html:9
+msgid "show video"
+msgstr ""
+
+#: searx/templates/oscar/result_templates/videos.html:9
+msgid "hide video"
+msgstr ""
+
msgid "Localization"
msgstr ""
@@ -404,15 +420,9 @@ msgstr "General"
msgid "music"
msgstr "Música"
-msgid "social media"
-msgstr "Medios sociales"
-
msgid "images"
msgstr "Imágenes"
-msgid "videos"
-msgstr "Vídeos"
-
msgid "it"
msgstr "TIC"
diff --git a/searx/translations/fr/LC_MESSAGES/messages.mo b/searx/translations/fr/LC_MESSAGES/messages.mo
index ed0d6a4e..37507f2f 100644
Binary files a/searx/translations/fr/LC_MESSAGES/messages.mo and b/searx/translations/fr/LC_MESSAGES/messages.mo differ
diff --git a/searx/translations/fr/LC_MESSAGES/messages.po b/searx/translations/fr/LC_MESSAGES/messages.po
index 44e6b96c..6afff387 100644
--- a/searx/translations/fr/LC_MESSAGES/messages.po
+++ b/searx/translations/fr/LC_MESSAGES/messages.po
@@ -11,7 +11,7 @@ msgid ""
msgstr ""
"Project-Id-Version: searx\n"
"Report-Msgid-Bugs-To: EMAIL@ADDRESS\n"
-"POT-Creation-Date: 2014-12-27 14:39+0100\n"
+"POT-Creation-Date: 2015-01-05 20:54+0100\n"
"PO-Revision-Date: 2014-12-14 21:00+0000\n"
"Last-Translator: Cqoicebordel \n"
"Language-Team: French "
@@ -22,11 +22,11 @@ msgstr ""
"Content-Transfer-Encoding: 8bit\n"
"Generated-By: Babel 1.3\n"
-#: searx/webapp.py:247
+#: searx/webapp.py:263
msgid "{minutes} minute(s) ago"
msgstr "il y a {minutes} minute(s)"
-#: searx/webapp.py:249
+#: searx/webapp.py:265
msgid "{hours} hour(s), {minutes} minute(s) ago"
msgstr "il y a {hours} heure(s), {minutes} minute(s)"
@@ -174,31 +174,31 @@ msgstr "retour"
#: searx/templates/courgette/results.html:12
#: searx/templates/default/results.html:12
-#: searx/templates/oscar/results.html:83
+#: searx/templates/oscar/results.html:87
msgid "Search URL"
msgstr "URL de recherche"
#: searx/templates/courgette/results.html:16
#: searx/templates/default/results.html:16
-#: searx/templates/oscar/results.html:88
+#: searx/templates/oscar/results.html:92
msgid "Download results"
msgstr "Télécharger les résultats"
#: searx/templates/courgette/results.html:34
#: searx/templates/default/results.html:42
-#: searx/templates/oscar/results.html:63
+#: searx/templates/oscar/results.html:67
msgid "Suggestions"
msgstr "Suggestions"
#: searx/templates/courgette/results.html:62
#: searx/templates/default/results.html:78
-#: searx/templates/oscar/results.html:37
+#: searx/templates/oscar/results.html:41
msgid "previous page"
msgstr "page précédente"
#: searx/templates/courgette/results.html:73
#: searx/templates/default/results.html:89
-#: searx/templates/oscar/results.html:45
+#: searx/templates/oscar/results.html:49
msgid "next page"
msgstr "page suivante"
@@ -277,7 +277,7 @@ msgstr "Modifier l'affichage de searx"
msgid "Search results"
msgstr "Résultats de recherche"
-#: searx/templates/oscar/results.html:78
+#: searx/templates/oscar/results.html:82
msgid "Links"
msgstr "Liens"
@@ -362,6 +362,14 @@ msgstr "Il y a un problème."
msgid "cached"
msgstr "en cache"
+#: searx/templates/oscar/result_templates/default.html:9
+msgid "show media"
+msgstr "afficher le média"
+
+#: searx/templates/oscar/result_templates/default.html:9
+msgid "hide media"
+msgstr "cacher le media"
+
#: searx/templates/oscar/result_templates/images.html:21
msgid "Get image"
msgstr "Voir l'image"
@@ -394,6 +402,14 @@ msgstr "Sources"
msgid "Leecher"
msgstr "Téléchargeurs"
+#: searx/templates/oscar/result_templates/videos.html:9
+msgid "show video"
+msgstr "afficher la vidéo"
+
+#: searx/templates/oscar/result_templates/videos.html:9
+msgid "hide video"
+msgstr "cacher la vidéo"
+
msgid "Localization"
msgstr "Localisation"
diff --git a/searx/translations/hu/LC_MESSAGES/messages.mo b/searx/translations/hu/LC_MESSAGES/messages.mo
index 69d4257b..f4d56666 100644
Binary files a/searx/translations/hu/LC_MESSAGES/messages.mo and b/searx/translations/hu/LC_MESSAGES/messages.mo differ
diff --git a/searx/translations/hu/LC_MESSAGES/messages.po b/searx/translations/hu/LC_MESSAGES/messages.po
index d750a535..16f02174 100644
--- a/searx/translations/hu/LC_MESSAGES/messages.po
+++ b/searx/translations/hu/LC_MESSAGES/messages.po
@@ -9,7 +9,7 @@ msgid ""
msgstr ""
"Project-Id-Version: searx\n"
"Report-Msgid-Bugs-To: EMAIL@ADDRESS\n"
-"POT-Creation-Date: 2014-12-27 14:39+0100\n"
+"POT-Creation-Date: 2015-01-05 20:54+0100\n"
"PO-Revision-Date: 2014-12-22 16:11+0000\n"
"Last-Translator: Adam Tauber \n"
"Language-Team: Hungarian "
@@ -20,11 +20,11 @@ msgstr ""
"Content-Transfer-Encoding: 8bit\n"
"Generated-By: Babel 1.3\n"
-#: searx/webapp.py:247
+#: searx/webapp.py:263
msgid "{minutes} minute(s) ago"
msgstr "{minutes} perce"
-#: searx/webapp.py:249
+#: searx/webapp.py:265
msgid "{hours} hour(s), {minutes} minute(s) ago"
msgstr "{hours} óra, {minutes} perce"
@@ -170,31 +170,31 @@ msgstr "vissza"
#: searx/templates/courgette/results.html:12
#: searx/templates/default/results.html:12
-#: searx/templates/oscar/results.html:83
+#: searx/templates/oscar/results.html:87
msgid "Search URL"
msgstr "Keresési URL"
#: searx/templates/courgette/results.html:16
#: searx/templates/default/results.html:16
-#: searx/templates/oscar/results.html:88
+#: searx/templates/oscar/results.html:92
msgid "Download results"
msgstr "Találatok letöltése"
#: searx/templates/courgette/results.html:34
#: searx/templates/default/results.html:42
-#: searx/templates/oscar/results.html:63
+#: searx/templates/oscar/results.html:67
msgid "Suggestions"
msgstr "Javaslatok"
#: searx/templates/courgette/results.html:62
#: searx/templates/default/results.html:78
-#: searx/templates/oscar/results.html:37
+#: searx/templates/oscar/results.html:41
msgid "previous page"
msgstr "előző oldal"
#: searx/templates/courgette/results.html:73
#: searx/templates/default/results.html:89
-#: searx/templates/oscar/results.html:45
+#: searx/templates/oscar/results.html:49
msgid "next page"
msgstr "következő oldal"
@@ -273,7 +273,7 @@ msgstr "Megjelenés"
msgid "Search results"
msgstr "Keresési eredmények"
-#: searx/templates/oscar/results.html:78
+#: searx/templates/oscar/results.html:82
msgid "Links"
msgstr "Linkek"
@@ -354,6 +354,14 @@ msgstr "Hiba történt"
msgid "cached"
msgstr "tárolt"
+#: searx/templates/oscar/result_templates/default.html:9
+msgid "show media"
+msgstr ""
+
+#: searx/templates/oscar/result_templates/default.html:9
+msgid "hide media"
+msgstr ""
+
#: searx/templates/oscar/result_templates/images.html:21
msgid "Get image"
msgstr "Kép megjelenítése"
@@ -386,6 +394,14 @@ msgstr "Seeder"
msgid "Leecher"
msgstr "Leecher"
+#: searx/templates/oscar/result_templates/videos.html:9
+msgid "show video"
+msgstr ""
+
+#: searx/templates/oscar/result_templates/videos.html:9
+msgid "hide video"
+msgstr ""
+
msgid "Localization"
msgstr "Nyelv"
diff --git a/searx/translations/it/LC_MESSAGES/messages.mo b/searx/translations/it/LC_MESSAGES/messages.mo
index 5c102b87..ce22605a 100644
Binary files a/searx/translations/it/LC_MESSAGES/messages.mo and b/searx/translations/it/LC_MESSAGES/messages.mo differ
diff --git a/searx/translations/it/LC_MESSAGES/messages.po b/searx/translations/it/LC_MESSAGES/messages.po
index bafa79e4..3a49ca7f 100644
--- a/searx/translations/it/LC_MESSAGES/messages.po
+++ b/searx/translations/it/LC_MESSAGES/messages.po
@@ -8,7 +8,7 @@ msgid ""
msgstr ""
"Project-Id-Version: searx\n"
"Report-Msgid-Bugs-To: EMAIL@ADDRESS\n"
-"POT-Creation-Date: 2014-12-27 14:39+0100\n"
+"POT-Creation-Date: 2015-01-05 20:54+0100\n"
"PO-Revision-Date: 2014-11-26 20:38+0000\n"
"Last-Translator: Adam Tauber \n"
"Language-Team: Italian "
@@ -19,11 +19,11 @@ msgstr ""
"Content-Transfer-Encoding: 8bit\n"
"Generated-By: Babel 1.3\n"
-#: searx/webapp.py:247
+#: searx/webapp.py:263
msgid "{minutes} minute(s) ago"
msgstr "di {minutes} minuti fa"
-#: searx/webapp.py:249
+#: searx/webapp.py:265
msgid "{hours} hour(s), {minutes} minute(s) ago"
msgstr "di {ore} h e {minutes} minuti fa"
@@ -171,31 +171,31 @@ msgstr "indietro"
#: searx/templates/courgette/results.html:12
#: searx/templates/default/results.html:12
-#: searx/templates/oscar/results.html:83
+#: searx/templates/oscar/results.html:87
msgid "Search URL"
msgstr "URL della ricerca"
#: searx/templates/courgette/results.html:16
#: searx/templates/default/results.html:16
-#: searx/templates/oscar/results.html:88
+#: searx/templates/oscar/results.html:92
msgid "Download results"
msgstr "Scarica i risultati"
#: searx/templates/courgette/results.html:34
#: searx/templates/default/results.html:42
-#: searx/templates/oscar/results.html:63
+#: searx/templates/oscar/results.html:67
msgid "Suggestions"
msgstr "Suggerimenti"
#: searx/templates/courgette/results.html:62
#: searx/templates/default/results.html:78
-#: searx/templates/oscar/results.html:37
+#: searx/templates/oscar/results.html:41
msgid "previous page"
msgstr "pagina precedente"
#: searx/templates/courgette/results.html:73
#: searx/templates/default/results.html:89
-#: searx/templates/oscar/results.html:45
+#: searx/templates/oscar/results.html:49
msgid "next page"
msgstr "pagina successiva"
@@ -271,7 +271,7 @@ msgstr ""
msgid "Search results"
msgstr ""
-#: searx/templates/oscar/results.html:78
+#: searx/templates/oscar/results.html:82
msgid "Links"
msgstr ""
@@ -352,6 +352,14 @@ msgstr ""
msgid "cached"
msgstr ""
+#: searx/templates/oscar/result_templates/default.html:9
+msgid "show media"
+msgstr ""
+
+#: searx/templates/oscar/result_templates/default.html:9
+msgid "hide media"
+msgstr ""
+
#: searx/templates/oscar/result_templates/images.html:21
msgid "Get image"
msgstr ""
@@ -384,6 +392,14 @@ msgstr ""
msgid "Leecher"
msgstr ""
+#: searx/templates/oscar/result_templates/videos.html:9
+msgid "show video"
+msgstr ""
+
+#: searx/templates/oscar/result_templates/videos.html:9
+msgid "hide video"
+msgstr ""
+
msgid "Localization"
msgstr ""
@@ -404,15 +420,9 @@ msgstr "generale"
msgid "music"
msgstr "musica"
-msgid "social media"
-msgstr "social media"
-
msgid "images"
msgstr "immagini"
-msgid "videos"
-msgstr "video"
-
msgid "it"
msgstr "it"
diff --git a/searx/translations/ja/LC_MESSAGES/messages.mo b/searx/translations/ja/LC_MESSAGES/messages.mo
index d44ee77a..0b25be7a 100644
Binary files a/searx/translations/ja/LC_MESSAGES/messages.mo and b/searx/translations/ja/LC_MESSAGES/messages.mo differ
diff --git a/searx/translations/ja/LC_MESSAGES/messages.po b/searx/translations/ja/LC_MESSAGES/messages.po
index 0a329ca0..c91fd1f8 100644
--- a/searx/translations/ja/LC_MESSAGES/messages.po
+++ b/searx/translations/ja/LC_MESSAGES/messages.po
@@ -9,7 +9,7 @@ msgid ""
msgstr ""
"Project-Id-Version: searx\n"
"Report-Msgid-Bugs-To: EMAIL@ADDRESS\n"
-"POT-Creation-Date: 2014-12-27 14:39+0100\n"
+"POT-Creation-Date: 2015-01-05 20:54+0100\n"
"PO-Revision-Date: 2014-11-26 20:38+0000\n"
"Last-Translator: Adam Tauber \n"
"Language-Team: Japanese "
@@ -20,11 +20,11 @@ msgstr ""
"Content-Transfer-Encoding: 8bit\n"
"Generated-By: Babel 1.3\n"
-#: searx/webapp.py:247
+#: searx/webapp.py:263
msgid "{minutes} minute(s) ago"
msgstr "{minutes}分前"
-#: searx/webapp.py:249
+#: searx/webapp.py:265
msgid "{hours} hour(s), {minutes} minute(s) ago"
msgstr "{hours}時間と{minutes}分前"
@@ -168,31 +168,31 @@ msgstr "バック"
#: searx/templates/courgette/results.html:12
#: searx/templates/default/results.html:12
-#: searx/templates/oscar/results.html:83
+#: searx/templates/oscar/results.html:87
msgid "Search URL"
msgstr ""
#: searx/templates/courgette/results.html:16
#: searx/templates/default/results.html:16
-#: searx/templates/oscar/results.html:88
+#: searx/templates/oscar/results.html:92
msgid "Download results"
msgstr "ダウンロードの結果"
#: searx/templates/courgette/results.html:34
#: searx/templates/default/results.html:42
-#: searx/templates/oscar/results.html:63
+#: searx/templates/oscar/results.html:67
msgid "Suggestions"
msgstr "提案"
#: searx/templates/courgette/results.html:62
#: searx/templates/default/results.html:78
-#: searx/templates/oscar/results.html:37
+#: searx/templates/oscar/results.html:41
msgid "previous page"
msgstr "前のページ"
#: searx/templates/courgette/results.html:73
#: searx/templates/default/results.html:89
-#: searx/templates/oscar/results.html:45
+#: searx/templates/oscar/results.html:49
msgid "next page"
msgstr "次のページ"
@@ -268,7 +268,7 @@ msgstr ""
msgid "Search results"
msgstr ""
-#: searx/templates/oscar/results.html:78
+#: searx/templates/oscar/results.html:82
msgid "Links"
msgstr ""
@@ -349,6 +349,14 @@ msgstr ""
msgid "cached"
msgstr ""
+#: searx/templates/oscar/result_templates/default.html:9
+msgid "show media"
+msgstr ""
+
+#: searx/templates/oscar/result_templates/default.html:9
+msgid "hide media"
+msgstr ""
+
#: searx/templates/oscar/result_templates/images.html:21
msgid "Get image"
msgstr ""
@@ -381,6 +389,14 @@ msgstr ""
msgid "Leecher"
msgstr ""
+#: searx/templates/oscar/result_templates/videos.html:9
+msgid "show video"
+msgstr ""
+
+#: searx/templates/oscar/result_templates/videos.html:9
+msgid "hide video"
+msgstr ""
+
msgid "Localization"
msgstr ""
@@ -401,15 +417,9 @@ msgstr "ウェブ"
msgid "music"
msgstr "音楽"
-msgid "social media"
-msgstr "ソーシャルメディア"
-
msgid "images"
msgstr "画像"
-msgid "videos"
-msgstr "動画"
-
msgid "it"
msgstr "情報技術"
diff --git a/searx/translations/nl/LC_MESSAGES/messages.mo b/searx/translations/nl/LC_MESSAGES/messages.mo
index afa9438e..df5e7f45 100644
Binary files a/searx/translations/nl/LC_MESSAGES/messages.mo and b/searx/translations/nl/LC_MESSAGES/messages.mo differ
diff --git a/searx/translations/nl/LC_MESSAGES/messages.po b/searx/translations/nl/LC_MESSAGES/messages.po
index 3d3a9def..e3be7a90 100644
--- a/searx/translations/nl/LC_MESSAGES/messages.po
+++ b/searx/translations/nl/LC_MESSAGES/messages.po
@@ -8,7 +8,7 @@ msgid ""
msgstr ""
"Project-Id-Version: searx\n"
"Report-Msgid-Bugs-To: EMAIL@ADDRESS\n"
-"POT-Creation-Date: 2014-12-27 14:39+0100\n"
+"POT-Creation-Date: 2015-01-05 20:54+0100\n"
"PO-Revision-Date: 2014-12-11 13:50+0000\n"
"Last-Translator: André Koot \n"
"Language-Team: Dutch "
@@ -19,11 +19,11 @@ msgstr ""
"Content-Transfer-Encoding: 8bit\n"
"Generated-By: Babel 1.3\n"
-#: searx/webapp.py:247
+#: searx/webapp.py:263
msgid "{minutes} minute(s) ago"
msgstr "{minutes} min geleden"
-#: searx/webapp.py:249
+#: searx/webapp.py:265
msgid "{hours} hour(s), {minutes} minute(s) ago"
msgstr "{hours} uur, {minutes} min geleden"
@@ -171,31 +171,31 @@ msgstr "terug"
#: searx/templates/courgette/results.html:12
#: searx/templates/default/results.html:12
-#: searx/templates/oscar/results.html:83
+#: searx/templates/oscar/results.html:87
msgid "Search URL"
msgstr "Zoek URL"
#: searx/templates/courgette/results.html:16
#: searx/templates/default/results.html:16
-#: searx/templates/oscar/results.html:88
+#: searx/templates/oscar/results.html:92
msgid "Download results"
msgstr "Downloaden zoekresultaten"
#: searx/templates/courgette/results.html:34
#: searx/templates/default/results.html:42
-#: searx/templates/oscar/results.html:63
+#: searx/templates/oscar/results.html:67
msgid "Suggestions"
msgstr "Suggesties"
#: searx/templates/courgette/results.html:62
#: searx/templates/default/results.html:78
-#: searx/templates/oscar/results.html:37
+#: searx/templates/oscar/results.html:41
msgid "previous page"
msgstr "vorige pagina"
#: searx/templates/courgette/results.html:73
#: searx/templates/default/results.html:89
-#: searx/templates/oscar/results.html:45
+#: searx/templates/oscar/results.html:49
msgid "next page"
msgstr "volgende pagina"
@@ -274,7 +274,7 @@ msgstr "Wijzig searx layout"
msgid "Search results"
msgstr "Zoekresultaten"
-#: searx/templates/oscar/results.html:78
+#: searx/templates/oscar/results.html:82
msgid "Links"
msgstr "Links"
@@ -357,6 +357,14 @@ msgstr "Er ging iets fout."
msgid "cached"
msgstr "gecached"
+#: searx/templates/oscar/result_templates/default.html:9
+msgid "show media"
+msgstr ""
+
+#: searx/templates/oscar/result_templates/default.html:9
+msgid "hide media"
+msgstr ""
+
#: searx/templates/oscar/result_templates/images.html:21
msgid "Get image"
msgstr "Toon afbeelding"
@@ -389,6 +397,14 @@ msgstr "Aanbieder"
msgid "Leecher"
msgstr "Ophaler"
+#: searx/templates/oscar/result_templates/videos.html:9
+msgid "show video"
+msgstr ""
+
+#: searx/templates/oscar/result_templates/videos.html:9
+msgid "hide video"
+msgstr ""
+
msgid "Localization"
msgstr "Vertaling"
diff --git a/searx/translations/tr/LC_MESSAGES/messages.mo b/searx/translations/tr/LC_MESSAGES/messages.mo
index 5d6c0498..2ea37052 100644
Binary files a/searx/translations/tr/LC_MESSAGES/messages.mo and b/searx/translations/tr/LC_MESSAGES/messages.mo differ
diff --git a/searx/translations/tr/LC_MESSAGES/messages.po b/searx/translations/tr/LC_MESSAGES/messages.po
index a39ae3fd..22190141 100644
--- a/searx/translations/tr/LC_MESSAGES/messages.po
+++ b/searx/translations/tr/LC_MESSAGES/messages.po
@@ -1,30 +1,30 @@
-# English translations for PROJECT.
+# English translations for .
# Copyright (C) 2014 ORGANIZATION
-# This file is distributed under the same license as the PROJECT project.
-#
+# This file is distributed under the same license as the project.
+#
# Translators:
# Caner Başaran , 2014
# FIRST AUTHOR , 2014
msgid ""
msgstr ""
-"Project-Id-Version: searx\n"
+"Project-Id-Version: searx\n"
"Report-Msgid-Bugs-To: EMAIL@ADDRESS\n"
-"POT-Creation-Date: 2014-12-27 14:39+0100\n"
+"POT-Creation-Date: 2015-01-05 20:54+0100\n"
"PO-Revision-Date: 2014-12-28 08:20+0000\n"
"Last-Translator: Caner Başaran \n"
-"Language-Team: Turkish (http://www.transifex.com/projects/p/searx/language/tr/)\n"
+"Language-Team: Turkish "
+"(http://www.transifex.com/projects/p/searx/language/tr/)\n"
+"Plural-Forms: nplurals=2; plural=(n > 1)\n"
"MIME-Version: 1.0\n"
-"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Type: text/plain; charset=utf-8\n"
"Content-Transfer-Encoding: 8bit\n"
"Generated-By: Babel 1.3\n"
-"Language: tr\n"
-"Plural-Forms: nplurals=2; plural=(n > 1);\n"
-#: searx/webapp.py:247
+#: searx/webapp.py:263
msgid "{minutes} minute(s) ago"
msgstr "{minutes} dakika() önce"
-#: searx/webapp.py:249
+#: searx/webapp.py:265
msgid "{hours} hour(s), {minutes} minute(s) ago"
msgstr "{hours} saat(), {minutes} dakika() önce"
@@ -142,9 +142,11 @@ msgstr "Engelle"
#: searx/templates/default/preferences.html:92
#: searx/templates/oscar/preferences.html:132
msgid ""
-"These settings are stored in your cookies, this allows us not to store this "
-"data about you."
-msgstr "Ayarlar çerezlerinizde saklanır. Verdiğiniz izinler, sizin hakkınızda veri saklamak için değil."
+"These settings are stored in your cookies, this allows us not to store "
+"this data about you."
+msgstr ""
+"Ayarlar çerezlerinizde saklanır. Verdiğiniz izinler, sizin hakkınızda "
+"veri saklamak için değil."
#: searx/templates/courgette/preferences.html:94
#: searx/templates/default/preferences.html:94
@@ -168,31 +170,31 @@ msgstr "geri"
#: searx/templates/courgette/results.html:12
#: searx/templates/default/results.html:12
-#: searx/templates/oscar/results.html:83
+#: searx/templates/oscar/results.html:87
msgid "Search URL"
msgstr "Arama Bağlantısı"
#: searx/templates/courgette/results.html:16
#: searx/templates/default/results.html:16
-#: searx/templates/oscar/results.html:88
+#: searx/templates/oscar/results.html:92
msgid "Download results"
msgstr "Arama sonuçlarını indir"
#: searx/templates/courgette/results.html:34
#: searx/templates/default/results.html:42
-#: searx/templates/oscar/results.html:63
+#: searx/templates/oscar/results.html:67
msgid "Suggestions"
msgstr "Öneriler"
#: searx/templates/courgette/results.html:62
#: searx/templates/default/results.html:78
-#: searx/templates/oscar/results.html:37
+#: searx/templates/oscar/results.html:41
msgid "previous page"
msgstr "önceki sayfa"
#: searx/templates/courgette/results.html:73
#: searx/templates/default/results.html:89
-#: searx/templates/oscar/results.html:45
+#: searx/templates/oscar/results.html:49
msgid "next page"
msgstr "sonraki sayfa"
@@ -221,7 +223,9 @@ msgstr "Gücümün kaynağı"
#: searx/templates/oscar/base.html:69
msgid "a privacy-respecting, hackable metasearch engine"
-msgstr "kişisel gizliliğe saygılı ve merak edenlerin kurcalayabildiği bir meta arama motoru"
+msgstr ""
+"kişisel gizliliğe saygılı ve merak edenlerin kurcalayabildiği bir meta "
+"arama motoru"
#: searx/templates/oscar/navbar.html:6
msgid "Toggle navigation"
@@ -258,7 +262,10 @@ msgid ""
"Change how forms are submited, learn more about request methods"
-msgstr "Aramaların nasıl gönderildiğini değiştir, istek yöntemleri hakkında daha fazla bilgi"
+msgstr ""
+"Aramaların nasıl gönderildiğini değiştir, istek yöntemleri hakkında daha fazla bilgi"
#: searx/templates/oscar/preferences.html:84
msgid "Change searx layout"
@@ -268,12 +275,11 @@ msgstr "searx yerleşim düzenini değiştir"
msgid "Search results"
msgstr "Arama sonuçları"
-#: searx/templates/oscar/results.html:78
+#: searx/templates/oscar/results.html:82
msgid "Links"
msgstr "Bağlantılar"
-#: searx/templates/oscar/search.html:6
-#: searx/templates/oscar/search_full.html:7
+#: searx/templates/oscar/search.html:6 searx/templates/oscar/search_full.html:7
msgid "Start search"
msgstr "Aramayı başlat"
@@ -311,7 +317,9 @@ msgstr "Uyarı!"
#: searx/templates/oscar/messages/js_disabled.html:3
msgid "Please enable JavaScript to use full functionality of this site."
-msgstr "Lütfen, bu sitenin tüm işlevlerini kullanmak için JavaScript'i etkinleştirin."
+msgstr ""
+"Lütfen, bu sitenin tüm işlevlerini kullanmak için JavaScript'i "
+"etkinleştirin."
#: searx/templates/oscar/messages/no_data_available.html:4
msgid "There is currently no data available. "
@@ -325,7 +333,9 @@ msgstr "Üzgünüz!"
msgid ""
"we didn't find any results. Please use another query or search in more "
"categories."
-msgstr "herhangi bir sonuç bulamadık. Lütfen, başka sorgu kullanın veya daha fazla kategoride arama yapın."
+msgstr ""
+"herhangi bir sonuç bulamadık. Lütfen, başka sorgu kullanın veya daha "
+"fazla kategoride arama yapın."
#: searx/templates/oscar/messages/save_settings_successfull.html:7
msgid "Well done!"
@@ -350,6 +360,14 @@ msgstr "Bazı bazı şeylerde problem olmuş."
msgid "cached"
msgstr "önbellek"
+#: searx/templates/oscar/result_templates/default.html:9
+msgid "show media"
+msgstr ""
+
+#: searx/templates/oscar/result_templates/default.html:9
+msgid "hide media"
+msgstr ""
+
#: searx/templates/oscar/result_templates/images.html:21
msgid "Get image"
msgstr "Görseli indir"
@@ -382,6 +400,14 @@ msgstr "Besleyenler"
msgid "Leecher"
msgstr "Sömürenler"
+#: searx/templates/oscar/result_templates/videos.html:9
+msgid "show video"
+msgstr ""
+
+#: searx/templates/oscar/result_templates/videos.html:9
+msgid "hide video"
+msgstr ""
+
msgid "Localization"
msgstr ""
@@ -419,3 +445,4 @@ msgstr "haberler"
msgid "map"
msgstr "harita"
+
diff --git a/utils/update-translations.sh b/utils/update-translations.sh
index bac7d3c4..2f9ab218 100755
--- a/utils/update-translations.sh
+++ b/utils/update-translations.sh
@@ -9,7 +9,7 @@ SEARX_DIR='searx'
pybabel extract -F babel.cfg -o messages.pot $SEARX_DIR
for f in `ls $SEARX_DIR'/translations/'`; do
- pybabel update -i messages.pot -d $SEARX_DIR'/translations/' -l $f
+ pybabel update -N -i messages.pot -d $SEARX_DIR'/translations/' -l $f
# TODO - need to fix category translations
sed -i 's/#~ //' $SEARX_DIR'/translations/'$f'/LC_MESSAGES/messages.po'
done
diff --git a/searx/engines/dailymotion.py b/searx/engines/dailymotion.py
index a5bffa86..03b1dbb8 100644
--- a/searx/engines/dailymotion.py
+++ b/searx/engines/dailymotion.py
@@ -6,12 +6,14 @@
# @using-api yes
# @results JSON
# @stable yes
# @parse url, title, thumbnail
#
# @todo set content-parameter with correct data
from urllib import urlencode
from json import loads
+from cgi import escape
+from datetime import datetime
# engine dependent config
categories = ['videos']
@@ -20,7 +22,9 @@ language_support = True
# search-url
# see http://www.dailymotion.com/doc/api/obj-video.html
-search_url = 'https://api.dailymotion.com/videos?fields=title,description,duration,url,thumbnail_360_url&sort=relevance&limit=5&page={pageno}&{query}' # noqa
+search_url = 'https://api.dailymotion.com/videos?fields=created_time,title,description,duration,url,thumbnail_360_url,id&sort=relevance&limit=5&page={pageno}&{query}' # noqa
+embedded_url = ''
# do search-request
@@ -51,14 +55,17 @@ def response(resp):
for res in search_res['list']:
title = res['title']
url = res['url']
- #content = res['description']
- content = ''
+ content = escape(res['description'])
thumbnail = res['thumbnail_360_url']
+ publishedDate = datetime.fromtimestamp(res['created_time'], None)
+ embedded = embedded_url.format(videoid=res['id'])
results.append({'template': 'videos.html',
'url': url,
'title': title,
'content': content,
+ 'publishedDate': publishedDate,
+ 'embedded': embedded,
'thumbnail': thumbnail})
# return results
@@ -6,12 +6,14 @@
# @results JSON
# @stable yes
-# @parse url, title, thumbnail
+# @parse url, title, thumbnail, publishedDate, embedded
#
# @todo set content-parameter with correct data
diff --git a/searx/engines/soundcloud.py b/searx/engines/soundcloud.py
index 164a569a..44374af6 100644
--- a/searx/engines/soundcloud.py
+++ b/searx/engines/soundcloud.py
@@ -6,10 +6,11 @@
# @using-api yes
# @results JSON
# @stable yes
# @parse url, title, content
from json import loads
-from urllib import urlencode
+from urllib import urlencode, quote_plus
+from dateutil import parser
# engine dependent config
categories = ['music']
@@ -27,6 +28,10 @@ search_url = url + 'search?{query}'\
'&linked_partitioning=1'\
'&client_id={client_id}' # noqa
+embedded_url = ''
+
# do search-request
def request(query, params):
@@ -50,10 +55,15 @@ def response(resp):
if result['kind'] in ('track', 'playlist'):
title = result['title']
content = result['description']
+ publishedDate = parser.parse(result['last_modified'])
+ uri = quote_plus(result['uri'])
+ embedded = embedded_url.format(uri=uri)
# append result
results.append({'url': result['permalink_url'],
'title': title,
+ 'publishedDate': publishedDate,
+ 'embedded': embedded,
'content': content})
# return results
@@ -6,10 +6,11 @@
# @results JSON
# @stable yes
-# @parse url, title, content
+# @parse url, title, content, publishedDate, embedded
from json import loads
diff --git a/searx/engines/vimeo.py b/searx/engines/vimeo.py
index 3949a729..39033c59 100644
--- a/searx/engines/vimeo.py
+++ b/searx/engines/vimeo.py
@@ -1,4 +1,4 @@
-## Vimeo (Videos)
+# Vimeo (Videos)
#
# @website https://vimeo.com/
# @provide-api yes (http://developer.vimeo.com/api),
@@ -7,15 +7,16 @@
# @using-api no (TODO, rewrite to api)
# @results HTML (using search portal)
# @stable no (HTML can change)
# @parse url, title, publishedDate, thumbnail
#
# @todo rewrite to api
# @todo set content-parameter with correct data
from urllib import urlencode
from lxml import html
+from HTMLParser import HTMLParser
+from searx.engines.xpath import extract_text
from dateutil import parser
-from cgi import escape
# engine dependent config
categories = ['videos']
@@ -32,6 +33,10 @@ title_xpath = './a/div[@class="data"]/p[@class="title"]'
content_xpath = './a/img/@src'
publishedDate_xpath = './/p[@class="meta"]//attribute::datetime'
+embedded_url = ''
+
# do search-request
def request(query, params):
@@ -46,13 +51,17 @@ def response(resp):
results = []
dom = html.fromstring(resp.text)
+ p = HTMLParser()
# parse results
for result in dom.xpath(results_xpath):
- url = base_url + result.xpath(url_xpath)[0]
- title = escape(html.tostring(result.xpath(title_xpath)[0], method='text', encoding='UTF-8').decode("utf-8"))
- thumbnail = result.xpath(content_xpath)[0]
- publishedDate = parser.parse(result.xpath(publishedDate_xpath)[0])
+ videoid = result.xpath(url_xpath)[0]
+ url = base_url + videoid
+ title = p.unescape(extract_text(result.xpath(title_xpath)))
+ thumbnail = extract_text(result.xpath(content_xpath)[0])
+ publishedDate = parser.parse(extract_text(
+ result.xpath(publishedDate_xpath)[0]))
+ embedded = embedded_url.format(videoid=videoid)
# append result
results.append({'url': url,
@@ -60,6 +69,7 @@ def response(resp):
'content': '',
'template': 'videos.html',
'publishedDate': publishedDate,
+ 'embedded': embedded,
'thumbnail': thumbnail})
# return results
@@ -7,15 +7,16 @@
# @results HTML (using search portal)
# @stable no (HTML can change)
-# @parse url, title, publishedDate, thumbnail
+# @parse url, title, publishedDate, thumbnail, embedded
#
# @todo rewrite to api
diff --git a/searx/engines/youtube.py b/searx/engines/youtube.py
index 973e799f..59f07c57 100644
--- a/searx/engines/youtube.py
+++ b/searx/engines/youtube.py
@@ -6,7 +6,7 @@
# @using-api yes
# @results JSON
# @stable yes
# @parse url, title, content, publishedDate, thumbnail
from json import loads
from urllib import urlencode
@@ -19,7 +19,11 @@ language_support = True
# search-url
base_url = 'https://gdata.youtube.com/feeds/api/videos'
-search_url = base_url + '?alt=json&{query}&start-index={index}&max-results=5' # noqa
+search_url = base_url + '?alt=json&{query}&start-index={index}&max-results=5'
+
+embedded_url = ''
# do search-request
@@ -60,6 +64,8 @@ def response(resp):
if url.endswith('&'):
url = url[:-1]
+ videoid = url[32:]
+
title = result['title']['$t']
content = ''
thumbnail = ''
@@ -72,12 +78,15 @@ def response(resp):
content = result['content']['$t']
+ embedded = embedded_url.format(videoid=videoid)
+
# append result
results.append({'url': url,
'title': title,
'content': content,
'template': 'videos.html',
'publishedDate': publishedDate,
+ 'embedded': embedded,
'thumbnail': thumbnail})
# return results
@@ -6,7 +6,7 @@
# @results JSON
# @stable yes
-# @parse url, title, content, publishedDate, thumbnail
+# @parse url, title, content, publishedDate, thumbnail, embedded
from json import loads
from urllib import urlencode